@@ -1,10 +1,9 @@
 ##  RUnit : A unit test framework for the R programming language
-##  Copyright (C) 2003-2008  Thomas Koenig, Matthias Burger, Klaus Juenemann
+##  Copyright (C) 2003-2009  Thomas Koenig, Matthias Burger, Klaus Juenemann
 ##
 ##  This program is free software; you can redistribute it and/or modify
 ##  it under the terms of the GNU General Public License as published by
-##  the Free Software Foundation; either version 2 of the License, or
-##  (at your option) any later version.
+##  the Free Software Foundation; version 2 of the License.
 ##
 ##  This program is distributed in the hope that it will be useful,
 ##  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +14,8 @@
 ##  along with this program; if not, write to the Free Software
 ##  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-##  $Id: htmlProtocol.r,v 1.26 2008/11/07 13:49:58 burgerm Exp $
+##  $Id$
+
 
 printHTMLProtocol <- function(testData,
                               fileName = "",
@@ -34,7 +34,7 @@ printHTMLProtocol <- function(testData,
   ##@in  separateFailureList : [logical] if TRUE (default) add a list of all failures
   ##@in  traceBackCutOff     : [integer] number of steps back in the trace back stack to be displayed
   ##@in  testFileToLinkMap   : [function] a function transforming the full name of the test file to a link location
-  ##@ret                     : [logical] TRUE if execution completed wo error
+  ##@ret                     : [logical] TRUE if execution completed w/o error
   ##
   ##@codestatus : testing
   
@@ -82,8 +82,7 @@ printHTMLProtocol <- function(testData,
   ## --------------------------------
 
   ## get singular or plural right
-  sop <- function(number, word, plext="s")
-  {
+  sop <- function(number, word, plext="s") {
     ifelse(number == 1, paste(number, word),
            paste(number, paste(word, plext, sep="")))
   }
@@ -112,8 +111,7 @@ printHTMLProtocol <- function(testData,
     tmp <- paste(testSuite, srcFileName, testFuncName, sep="_")
     if(asAnchor) {
       return(paste("#", gsub("/", "_", tmp), sep=""))
-    }
-    else {
+    } else {
       return(gsub("/", "_", tmp))
     }
   }
@@ -130,8 +128,7 @@ printHTMLProtocol <- function(testData,
           writeRaw(traceBack[i], htmlFile=fileName)
           writeEndTag("li", htmlFile=fileName)
         }
-      }
-      else {
+      } else {
         writeBeginTag("ol", htmlFile=fileName)
         for(i in traceBackCutOff:length(traceBack)) {
           writeBeginTag("li", htmlFile=fileName)
@@ -200,7 +197,7 @@ printHTMLProtocol <- function(testData,
     }
     writeEndTable(htmlFile=fileName)
   }
-  else {  ## skip 'deactivated' column if no functions have been deactivated
+  else {  ## skip 'deactivated' column if no function has been deactivated
     writeBeginTable(c("Name", "Test functions", "Errors", "Failures"),
                     width="60%",
                     htmlFile=fileName,
